@@ -234,7 +234,7 @@ pred_first_fit <- function(gen_model, lambda = exp(seq(-16,-24, length.out = 100
   X[1,] <- sqrt(K)*p$p
   diag(X[2:(n_mut_types * n_genes + 1),]) <- sqrt(p$p)
   Y <- c(sqrt(K), sqrt(p$p))
-  Y[setdiff(2:(n_mut_types * n_genes + 1), 1 + p$bs)] <- 0
+  Y[setdiff(2:(n_mut_types * n_genes + 1), 1 + p$bc)] <- 0
 
   message("Fitting")
   fit <- gglasso::gglasso(x = X, y = Y, loss = "ls", lambda = lambda,
@@ -341,7 +341,7 @@ pred_refit_panel <- function(pred_first = NULL, gene_lengths = NULL, model = "T"
       p_panel <- pred_first$p[cols_panel]
       p_reduced <- unlist(purrr::map(1:n_mut_types, ~sum(p_panel[seq(., length(p_panel), n_mut_types)])))
       names(p_reduced) <- pred_first$names$mut_types_list
-      X_panel <- diag(p_reduced) + pred_first$K * p_reduced %*% t(p_reduced)
+      X_panel <- diag(x = p_reduced, nrow = length(p_reduced)) + pred_first$K * p_reduced %*% t(p_reduced)
       Y_panel <- (pred_first$K + (pred_first$names$mut_types_list %in% marker_mut_types))*p_reduced
       w_panel <- solve(X_panel) %*% Y_panel
       beta <- Matrix::Matrix(0, nrow = n_genes * n_mut_types, ncol = 1, sparse = TRUE)
